export default {
  color: ["#4d4d4d", "#3a5897", "#007bb6", "#7094db", "#0080ff", "#b3b3ff", "#00bdec", "#33ccff", "#ccddff", "#eeeeee"],
  title: {
    textStyle: {
      fontWeight: "normal",
      color: "#00aecd",
    },
  },
  visualMap: {
    color: ["#00aecd", "#a2d4e6"],
  },
  toolbox: {
    color: ["#00aecd", "#00aecd", "#00aecd", "#00aecd"],
  },
  tooltip: {
    backgroundColor: "rgba(0,0,0,0.5)",
    axisPointer: {
      type: "line",
      lineStyle: {
        color: "#00aecd",
        type: "dashed",
      },
      crossStyle: {
        color: "#00aecd",
      },
      shadowStyle: {
        color: "rgba(200,200,200,0.3)",
      },
    },
  },
  dataZoom: {
    dataBackgroundColor: "#eee",
    fillerColor: "rgba(144,197,237,0.2)",
    handleColor: "#00aecd",
  },
  timeline: {
    lineStyle: {
      color: "#00aecd",
    },
    controlStyle: {
      color: "#00aecd",
    },
    emphasis: {
      controlStyle: {
        color: "#00aecd",
      },
    },
  },
  candlestick: {
    itemStyle: {
      color: "#ddd",
      color0: "#eee",
    },
    lineStyle: {
      width: 1,
      color: "#33ccff",
      color0: "#1bb4cf",
    },
    areaStyle: {
      color: "#7094db",
      color0: "#33ccff",
    },
  },
  chord: {
    padding: 4,
    itemStyle: {
      color: "#7094db",
      borderWidth: 1,
      borderColor: "rgba(128, 128, 128, 0.5)",
    },
    lineStyle: {
      color: "rgba(128, 128, 128, 0.5)",
    },
    areaStyle: {
      color: "#33ccff",
    },
  },
  graph: {
    itemStyle: {
      color: "#7094db",
    },
    linkStyle: {
      color: "#33ccff",
    },
  },
  map: {
    itemStyle: {
      color: "#7094db",
    },
    areaStyle: {
      color: "#33ccff",
    },
    label: {
      color: "#ddd",
    },
  },
  gauge: {
    axisLine: {
      lineStyle: {
        color: [
          [0.2, "#dddddd"],
          [0.8, "#00aecd"],
          [1, "#33ccff"],
        ],
        width: 8,
      },
    },
  },
  series: [],
};
