export default {
  color: ["#8b1a2d", "#a7314b", "#e6004c", "#ff8066", "#8e5c4e", "#ff1a66", "#d6c582", "#f0d4af"],
  title: {
    textStyle: {
      fontWeight: "normal",
      color: "#8b1a2d",
    },
  },
  visualMap: {
    color: ["#8b1a2d", "#a7314b"],
  },
  toolbox: {
    color: ["#8b1a2d", "#8b1a2d", "#8b1a2d", "#8b1a2d"],
  },
  tooltip: {
    backgroundColor: "rgba(0,0,0,0.5)",
    axisPointer: {
      type: "line",
      lineStyle: {
        color: "#8b1a2d",
        type: "dashed",
      },
      crossStyle: {
        color: "#8b1a2d",
      },
      shadowStyle: {
        color: "rgba(200,200,200,0.3)",
      },
    },
  },
  dataZoom: {
    dataBackgroundColor: "#eee",
    fillerColor: "rgba(200,200,200,0.2)",
    handleColor: "#8b1a2d",
  },
  timeline: {
    lineStyle: {
      color: "#8b1a2d",
    },
    controlStyle: {
      color: "#8b1a2d",
      borderColor: "#8b1a2d",
    },
  },
  candlestick: {
    itemStyle: {
      color: "#a7314b",
      color0: "#d6c582",
    },
    lineStyle: {
      width: 1,
      color: "#8e5c4e",
      color0: "#f0d4af",
    },
    areaStyle: {
      color: "#8b1a2d",
      color0: "#ff8066",
    },
  },
  map: {
    itemStyle: {
      color: "#8b1a2d",
    },
    areaStyle: {
      color: "#ff8066",
    },
    label: {
      color: "#c12e34",
    },
  },
  graph: {
    itemStyle: {
      color: "#ff8066",
    },
    linkStyle: {
      color: "#8b1a2d",
    },
  },
  gauge: {
    axisLine: {
      lineStyle: {
        color: [
          [0.2, "#a7314b"],
          [0.8, "#8b1a2d"],
          [1, "#8e5c4e"],
        ],
        width: 8,
      },
    },
  },
  series: [],
};
