export default {
  color: ["#59535e", "#e7dcef", "#f1baf3", "#5d4970", "#372049", "#c0b2cd", "#ffccff", "#f2f0f5"],
  title: {
    textStyle: {
      fontWeight: "normal",
      color: "#59535e",
    },
  },
  visualMap: {
    color: ["#59535e", "#e7dcef"],
  },
  toolbox: {
    color: ["#59535e", "#59535e", "#59535e", "#59535e"],
  },
  tooltip: {
    backgroundColor: "rgba(0,0,0,0.5)",
    axisPointer: {
      type: "line",
      lineStyle: {
        color: "#59535e",
        type: "dashed",
      },
      crossStyle: {
        color: "#59535e",
      },
      shadowStyle: {
        color: "rgba(200,200,200,0.3)",
      },
    },
  },
  dataZoom: {
    dataBackgroundColor: "#eee",
    fillerColor: "rgba(200,200,200,0.2)",
    handleColor: "#59535e",
  },
  timeline: {
    lineStyle: {
      color: "#59535e",
    },
    controlStyle: {
      color: "#59535e",
      borderColor: "#59535e",
    },
  },
  candlestick: {
    itemStyle: {
      color: "#e7dcef",
      color0: "#f1baf3",
    },
    lineStyle: {
      width: 1,
      color: "#372049",
      color0: "#5d4970",
    },
    areaStyle: {
      color: "#59535e",
      color0: "#e7dcef",
    },
  },
  chord: {
    padding: 4,
    itemStyle: {
      color: "#59535e",
      borderWidth: 1,
      borderColor: "rgba(128, 128, 128, 0.5)",
    },
    lineStyle: {
      color: "rgba(128, 128, 128, 0.5)",
    },
    areaStyle: {
      color: "#e7dcef",
    },
  },
  map: {
    itemStyle: {
      color: "#ddd",
    },
    areaStyle: {
      color: "#f1baf3",
    },
    label: {
      color: "#c12e34",
    },
  },
  graph: {
    itemStyle: {
      color: "#59535e",
    },
    linkStyle: {
      color: "#59535e",
    },
  },
  gauge: {
    axisLine: {
      lineStyle: {
        color: [
          [0.2, "#e7dcef"],
          [0.8, "#59535e"],
          [1, "#372049"],
        ],
        width: 8,
      },
    },
  },
  series: [],
};
