export default {
  color: ["#458c6b", "#f2da87", "#d9a86c", "#d94436", "#a62424", "#76bc9b", "#cce6da", "#eeeeee"],
  backgroundColor: "#333",
  tooltip: {
    axisPointer: {
      lineStyle: {
        color: "#eee",
      },
      crossStyle: {
        color: "#eee",
      },
    },
  },
  legend: {
    textStyle: {
      color: "#eee",
    },
  },
  title: {
    textStyle: {
      color: "#eee",
    },
  },
  toolbox: {
    iconStyle: {
      borderColor: "#eee",
    },
  },
  dataZoom: {
    dataBackgroundColor: "#eee",
    fillerColor: "rgba(200,200,200,0.2)",
    handleColor: "#458c6b",
  },
  timeline: {
    itemStyle: {
      color: "#f2da87",
    },
    lineStyle: {
      color: "#eee",
    },
    controlStyle: {
      color: "#eee",
      borderColor: "#eee",
    },
    label: {
      color: "#eee",
    },
  },
  timeAxis: {
    axisLine: {
      lineStyle: {
        color: "#eee",
      },
    },
    axisTick: {
      lineStyle: {
        color: "#eee",
      },
    },
    axisLabel: {
      color: "#eee",
    },
    splitLine: {
      lineStyle: {
        type: "dashed",
        color: "#aaa",
      },
    },
    splitArea: {
      areaStyle: {
        color: "#eee",
      },
    },
  },
  logAxis: {
    axisLine: {
      lineStyle: {
        color: "#eee",
      },
    },
    axisTick: {
      lineStyle: {
        color: "#eee",
      },
    },
    axisLabel: {
      color: "#eee",
    },
    splitLine: {
      lineStyle: {
        type: "dashed",
        color: "#aaa",
      },
    },
    splitArea: {
      areaStyle: {
        color: "#eee",
      },
    },
  },
  valueAxis: {
    axisLine: {
      lineStyle: {
        color: "#eee",
      },
    },
    axisTick: {
      lineStyle: {
        color: "#eee",
      },
    },
    axisLabel: {
      color: "#eee",
    },
    splitLine: {
      lineStyle: {
        type: "dashed",
        color: "#aaa",
      },
    },
    splitArea: {
      areaStyle: {
        color: "#eee",
      },
    },
  },
  categoryAxis: {
    axisLine: {
      lineStyle: {
        color: "#eee",
      },
    },
    axisTick: {
      lineStyle: {
        color: "#eee",
      },
    },
    axisLabel: {
      color: "#eee",
    },
    splitLine: {
      lineStyle: {
        type: "dashed",
        color: "#aaa",
      },
      show: false,
    },
    splitArea: {
      areaStyle: {
        color: "#eee",
      },
    },
  },
  line: {
    symbol: "circle",
  },
  graph: {
    color: ["#458c6b", "#f2da87", "#d9a86c", "#d94436", "#a62424", "#76bc9b", "#cce6da", "#eeeeee"],
  },
  gauge: {
    axisLine: {
      lineStyle: {
        color: [
          [0.2, "#f2da87"],
          [0.8, "#458c6b"],
          [1, "#a62424"],
        ],
        width: 8,
      },
    },
  },
  series: [],
};
